@@ -398,6 +398,18 @@ def backup_completer(prefix, parsed_args, **kwargs):
             type=check_positive,
             metavar="NJOBS",
         ),
+        argument(
+            "--jobs-start-batch-period",
+            help="The time period in seconds over which a single batch of jobs will "
+            "be started.",
+            type=check_positive,
+        ),
+        argument(
+            "--jobs-start-batch-size",
+            help="The maximum number of parallel Rsync jobs to start in a single "
+            "batch.",
+            type=check_positive,
+        ),
         argument(
             "--bwlimit",
             help="maximum transfer rate in kilobytes per second. "
@@ -460,6 +472,12 @@ def backup(args):
             server.postgres.immediate_checkpoint = args.immediate_checkpoint
         if args.jobs is not None:
             server.config.parallel_jobs = args.jobs
+        if args.jobs_start_batch_size is not None:
+            server.config.parallel_jobs_start_batch_size = args.jobs_start_batch_size
+        if args.jobs_start_batch_period is not None:
+            server.config.parallel_jobs_start_batch_period = (
+                args.jobs_start_batch_period
+            )
         if hasattr(args, "bwlimit"):
             server.config.bandwidth_limit = args.bwlimit
         with closing(server):
@@ -682,6 +700,17 @@ def rebuild_xlogdb(args):
             type=check_positive,
             metavar="NJOBS",
         ),
+        argument(
+            "--jobs-start-batch-period",
+            help="The time period in seconds over which a single batch of jobs will "
+            "be started.",
+            type=check_positive,
+        ),
+        argument(
+            "--jobs-start-batch-size",
+            help="The maximum number of Rsync jobs to start in a single batch.",
+            type=check_positive,
+        ),
         argument(
             "--get-wal",
             help="Enable the get-wal option during the recovery.",
@@ -739,6 +768,14 @@ def rebuild_xlogdb(args):
                 "backup."
             ),
         ),
+        argument(
+            "--recovery-conf-filename",
+            dest="recovery_conf_filename",
+            help=(
+                "Name of the file to which recovery configuration options will be "
+                "added for PostgreSQL 12 and later (default: postgresql.auto.conf)."
+            ),
+        ),
         argument(
             "--snapshot-recovery-instance",
             help="Instance where the disks recovered from the snapshots are attached",
@@ -847,6 +884,10 @@ def recover(args):
             server.config.recovery_options.remove(RecoveryOptions.GET_WAL)
     if args.jobs is not None:
         server.config.parallel_jobs = args.jobs
+    if args.jobs_start_batch_size is not None:
+        server.config.parallel_jobs_start_batch_size = args.jobs_start_batch_size
+    if args.jobs_start_batch_period is not None:
+        server.config.parallel_jobs_start_batch_period = args.jobs_start_batch_period
     if hasattr(args, "bwlimit"):
         server.config.bandwidth_limit = args.bwlimit
 
@@ -942,6 +983,7 @@ def recover(args):
                 remote_command=args.remote_ssh_command,
                 target_action=getattr(args, "target_action", None),
                 standby_mode=getattr(args, "standby_mode", None),
+                recovery_conf_filename=args.recovery_conf_filename,
                 **snapshot_kwargs
             )
         except RecoveryException as exc:
