@@ -159,7 +159,6 @@ def main(args=None):
             raise SystemExit(0)
 
         with closing(cloud_interface):
-
             # TODO: Should the setup be optional?
             cloud_interface.setup_bucket()
 
@@ -361,6 +360,11 @@ def parse_arguments(args=None):
         "--snapshot-gcp-project",
         help="GCP project under which disk snapshots should be stored",
     )
+    gcs_arguments.add_argument(
+        "--kms-key-name",
+        help="The name of the GCP KMS key which should be used for encrypting the "
+        "uploaded data in GCS.",
+    )
     add_tag_argument(
         parser,
         name="tags",
@@ -373,6 +377,12 @@ def parse_arguments(args=None):
         "Allowed values: 'AES256'|'aws:kms'.",
         choices=["AES256", "aws:kms"],
     )
+    s3_arguments.add_argument(
+        "--sse-kms-key-id",
+        help="The AWS KMS key ID that should be used for encrypting the uploaded data "
+        "in S3. Can be specified using the key ID on its own or using the full ARN for "
+        "the key. Only allowed if `-e/--encryption` is set to `aws:kms`.",
+    )
     azure_arguments.add_argument(
         "--encryption-scope",
         help="The name of an encryption scope defined in the Azure Blob Storage "
