@@ -54,6 +54,16 @@ def _make_s3_cloud_interface(config, cloud_interface_kwargs):
     )
     if "encryption" in config:
         cloud_interface_kwargs["encryption"] = config.encryption
+    if "sse_kms_key_id" in config:
+        if (
+            config.sse_kms_key_id is not None
+            and "encryption" in config
+            and config.encryption != "aws:kms"
+        ):
+            raise CloudProviderOptionUnsupported(
+                'Encryption type must be "aws:kms" if SSE KMS Key ID is specified'
+            )
+        cloud_interface_kwargs["sse_kms_key_id"] = config.sse_kms_key_id
     return S3CloudInterface(**cloud_interface_kwargs)
 
 
@@ -102,6 +112,16 @@ def _make_google_cloud_interface(config, cloud_interface_kwargs):
     from barman.cloud_providers.google_cloud_storage import GoogleCloudInterface
 
     cloud_interface_kwargs["jobs"] = 1
+    if "kms_key_name" in config:
+        if (
+            config.kms_key_name is not None
+            and "snapshot_instance" in config
+            and config.snapshot_instance is not None
+        ):
+            raise CloudProviderOptionUnsupported(
+                "KMS key cannot be specified for snapshot backups"
+            )
+        cloud_interface_kwargs["kms_key_name"] = config.kms_key_name
     return GoogleCloudInterface(**cloud_interface_kwargs)
 
 
@@ -125,7 +145,6 @@ def get_cloud_interface(config):
     elif config.cloud_provider == "azure-blob-storage":
         return _make_azure_cloud_interface(config, cloud_interface_kwargs)
     elif config.cloud_provider == "google-cloud-storage":
-
         return _make_google_cloud_interface(config, cloud_interface_kwargs)
     else:
         raise CloudProviderUnsupported(
