@@ -460,6 +460,8 @@ class ServerConfig(object):
         "minimum_redundancy",
         "network_compression",
         "parallel_jobs",
+        "parallel_jobs_start_batch_period",
+        "parallel_jobs_start_batch_size",
         "path_prefix",
         "post_archive_retry_script",
         "post_archive_script",
@@ -535,6 +537,8 @@ class ServerConfig(object):
         "minimum_redundancy",
         "network_compression",
         "parallel_jobs",
+        "parallel_jobs_start_batch_period",
+        "parallel_jobs_start_batch_size",
         "path_prefix",
         "post_archive_retry_script",
         "post_archive_script",
@@ -593,6 +597,8 @@ class ServerConfig(object):
         "minimum_redundancy": "0",
         "network_compression": "false",
         "parallel_jobs": "1",
+        "parallel_jobs_start_batch_period": "1",
+        "parallel_jobs_start_batch_size": "10",
         "recovery_options": "",
         "create_slot": "manual",
         "retention_policy_mode": "auto",
@@ -633,6 +639,8 @@ class ServerConfig(object):
         "max_incoming_wals_queue": int,
         "network_compression": parse_boolean,
         "parallel_jobs": int,
+        "parallel_jobs_start_batch_period": int,
+        "parallel_jobs_start_batch_size": int,
         "recovery_options": RecoveryOptions,
         "recovery_staging_path": parse_recovery_staging_path,
         "create_slot": parse_create_slot,
